@@ -15,7 +15,7 @@
 
 This module contains various implementations of `MailDeliverys`.
 
-$Id: delivery.py 107770 2010-01-07 07:11:43Z kobold $
+$Id: delivery.py 108107 2010-01-13 13:32:26Z kobold $
 """
 __docformat__ = 'restructuredtext'
 
@@ -32,6 +32,9 @@ from zope.sendmail.maildir import Maildir
 from transaction.interfaces import IDataManager
 import transaction
 
+# BBB: this import is needed for backward compatibility with older versions of
+# zope.sendmail which defined QueueProcessorThread in this module
+from zope.sendmail.queue import QueueProcessorThread
 
 class MailDataManager(object):
     implements(IDataManager)
