@@ -13,7 +13,7 @@
 ##############################################################################
 """Read/write access to `Maildir` folders.
 
-$Id: maildir.py 107751 2010-01-06 20:38:46Z kobold $
+$Id: maildir.py 109588 2010-03-03 09:57:07Z kobold $
 """
 __docformat__ = 'restructuredtext'
 
@@ -114,6 +114,12 @@ class Maildir(object):
                                     join(subdir_new, unique))
 
 
+def _encode_utf8(s):
+    if isinstance(s, unicode):
+        s = s.encode('utf-8')
+    return s
+
+
 class MaildirMessageWriter(object):
     """See `zope.sendmail.interfaces.IMaildirMessageWriter`"""
 
@@ -127,9 +133,10 @@ class MaildirMessageWriter(object):
         self._aborted = False
 
     def write(self, data):
-        self._fd.write(data)
+        self._fd.write(_encode_utf8(data))
 
     def writelines(self, lines):
+        lines = map(_encode_utf8, lines)
         self._fd.writelines(lines)
 
     def close(self):
