@@ -13,10 +13,10 @@
 ##############################################################################
 """Mail delivery names vocabulary test
 
-$Id: test_vocabulary.py 106772 2009-12-18 20:27:54Z kobold $
+$Id: test_vocabulary.py 110390 2010-04-01 12:33:34Z mgedmin $
 """
 import unittest
-from zope.testing.doctest import DocTestSuite
+from doctest import DocTestSuite
 from zope.component.testing import setUp, tearDown
 
 def test_suite():
